# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.1](https://github.com/agntcy/slim/compare/slim-controller-v0.1.0...slim-controller-v0.1.1) - 2025-05-14

### Other

- *(slim-controller)* release v0.1.0 ([#250](https://github.com/agntcy/slim/pull/250))

## [0.1.0](https://github.com/agntcy/slim/releases/tag/slim-controller-v0.1.0) - 2025-05-14

### Added

- implement control API ([#147](https://github.com/agntcy/slim/pull/147))

### Fixed

- *(datapath)* keep protobuf in crate ([#248](https://github.com/agntcy/slim/pull/248))

### Other

- add integration test suite ([#233](https://github.com/agntcy/slim/pull/233))
